@@ -1,4 +1,4 @@
-VERSION = '0.6'
+VERSION = '0.7'
 
 from .design_flute import Design_tapered_pflute, Design_straight_pflute, Design_tapered_folk_flute, Design_straight_folk_flute
 from .make_flute import Make_flute
@@ -9,11 +9,13 @@ from .make_shawm import Make_shawm
 from .make_mouthpiece import Make_mouthpiece
 from .make_bauble import Make_bauble
 
-from .design_whistle import Design_folk_whistle, Design_three_hole_whistle
+from .design_whistle import Design_folk_whistle, Design_recorder, Design_three_hole_whistle
 from .make_whistle import Make_whistle
 
 from .make_panpipe import Make_panpipe
 
+from .make_reed import Make_reed
+
 from .all import All
 
 def main():
@@ -31,6 +33,7 @@ def main():
             
             'Whistles',
             Design_folk_whistle,
+            Design_recorder,
             Design_three_hole_whistle,
             Make_whistle,
             
@@ -40,14 +43,15 @@ def main():
             Make_shawm,
             Make_mouthpiece,
             Make_bauble,
+            #Make_reed,
             
             'Panpipes',        
             Make_panpipe,
             
-            'Everything',        
-            All,
-            '"demakein all:" uses the nesoni make system, see flags below.',
+            #'Everything',        
+            #All,
+            #'"demakein all:" uses the nesoni make system, see flags below.',
         ],
-        show_make_flags=True,
+        show_make_flags=False,
         )
 
