@@ -690,7 +690,8 @@ class Instrument_designer(config.Action_with_output_dir):
             
             if i < self.n_holes-1:
                 this_y = min(text_y, -0.5*(self.instrument.hole_positions[i]+self.instrument.hole_positions[i+1]))
-                text_y = diagram.text(text_x + 45.0, this_y,
+                #text_y = 
+                diagram.text(text_x + 45.0, this_y,
                    '%.1fmm' % (self.instrument.hole_positions[i+1]-self.instrument.hole_positions[i])
                 )
         
