@@ -94,12 +94,29 @@ class Make(config.Action_with_output_dir, Make_base):
 class Working(object): pass
 
 @config.String_flag('prefix', 'Output file prefix (useful if you want to make your design several different ways).')
+@config.Bool_flag('fingerpads',
+    'Flatten area around finger holes, '
+    'possibly producing a better seal.'
+    )
+@config.String_flag('join',
+    'Printing: Join type, options are:\n'
+    'weld - ABS pieces to be joined by acetone welding, or similar.\n'
+    'straight - Straight socket.\n'
+    'taper - Tapered socket.\n'
+    )
 @config.Float_flag('gap', 
-    'Printing: Amount of gap all around in the joins between segments. '
+    'Printing: Amount of gap all around in the joins between segments '
+    'for straight or tapered joins. '
     'The best value for this will depend on the accuracy of your printer. '
     'If a joint is too loose and leaks, it can be sealed using wax or similar.')
+@config.Bool_flag('thick_sockets',
+    'Add some extra thickness around sockets.'
+    )
 class Make_instrument(config.Action_with_working_dir, Make_base):
-    gap = 0.35
+    gap = 0.25
+    fingerpads = False
+    join = 'weld'
+    thick_sockets = False
     prefix = ''
 
     def _before_run(self):
@@ -141,7 +158,8 @@ class Make_instrument(config.Action_with_working_dir, Make_base):
                 
             cross_section = shape.squared_circle(xpad[i], ypad[i]).with_effective_diameter
             
-            h1 = inside_height*0.75
+            #h1 = inside_height*0.75
+            h1 = inside_height*0.5
             shift1 = math.sin(radians)*h1
             h2 = height*1.5
             shift2 = math.sin(radians)*h2
@@ -158,7 +176,7 @@ class Make_instrument(config.Action_with_working_dir, Make_base):
             hole.rotate(0,0,1, hole_horiz_angles[i])
             hole.move(0,0,pos + shift)
             
-            if with_fingerpad[i]:
+            if with_fingerpad[i] and self.fingerpads:
                 pad_height = height*0.5+0.5*math.sqrt(height**2-(hole_diameters[i]*0.5)**2)
                 pad_depth = (pad_height-inside_height)
                 pad_mid = pad_depth*0.25
@@ -208,6 +226,8 @@ class Make_instrument(config.Action_with_working_dir, Make_base):
     def segment(self, cuts, length, up=False):
         working = self.working
         remainder = working.instrument.copy()
+        if self.thick_sockets:
+            bore = self.working.bore
         inner = working.spec.inner
         outer = working.spec.outer
         
@@ -215,27 +235,87 @@ class Make_instrument(config.Action_with_working_dir, Make_base):
             cuts = [ length-item for item in cuts[::-1] ]
             remainder.rotate(0,1,0, 180)
             remainder.move(0,0,length)
+            if self.thick_sockets:
+                bore = bore.copy()
+                bore.rotate(0,1,0, 180)
+                bore.move(0,0,length)
+                
             inner = inner.reversed().moved(length)
             outer = outer.reversed().moved(length)
         
+        if self.join == 'weld':
+            socket = self._weld_join
+        elif self.join == 'straight':
+            socket = self._straight_socket 
+        elif self.join == 'taper':
+            socket = self._tapered_socket
+        else:
+            assert False, 'Unknown join type: '+self.join
+        
         shapes = [ ]
         for cut in cuts:
             d1 = inner(cut)
-            d3 = outer(cut)
+            d4 = outer(cut)
+            d5 = outer.maximum() * 2.0
+            p1 = cut-d4*0.4
+            p3 = cut+d4*0.4
+            
+            if self.thick_sockets:
+                d4_orig = d4
+                d4 += min(d4*0.2, (d4-d1)*0.5)
+                prof_thicker = profile.Profile(
+                    [ p1-(d4-d4_orig), p1, p3 ],
+                    [ (d1+d4)*0.5, d4, d4 ],
+                )
+                thicker = shape.extrude_profile(prof_thicker)
+                thicker.remove(bore)
+                remainder.add(thicker)
+                del thicker
+            
+            mask_inside, mask_outside = socket(
+                p1,
+                p3,
+                length,
+                d1,
+                d4,
+                d5
+                )
+            
+            item = remainder.copy()
+            item.remove(mask_outside)                
+            remainder.clip(mask_inside)
+            shapes.append(item)
+            del mask_inside
+            del mask_outside
+        shapes.append(remainder)
+        shapes = shapes[::-1]
+        
+        for i, item in enumerate(shapes):
+            item.rotate(0,1,0, 180)
+            item.position_nicely()
+            self.save(item, '%d-piece-%d' % (len(shapes),i+1))
+        
+        size = outer.maximum() * 4.0
+        template = pack.Pack(size,size,5000.0)
+        packables = [ [pack.Packable([item], 0.0, 1.0)] for item in shapes ]
+        [ packed ] = pack.pack(template, packables)
+        self.save(packed.render_print(), '%d-piece-all' % len(shapes))
+        
+        #self.working.segments = shapes
+
+    def _straight_socket(
+                self,
+                p1,
+                p3,
+                length,
+                d1,
+                d3,
+                d4
+                ):       
             d2 = (d1+d3) / 2.0
             
-            
-            d4 = outer.maximum() * 2.0
-            p1 = cut-d2*0.4
-            p3 = cut+d2*0.4
-            p2 = p1 + (d3-d1)*0.25
-        
-            #0.4mm clearance all around
-            # radius -> diameter    * 2
-            # adjust both diamerers / 2
-            # net effect            * 1
-            # 0.4mm was loose
-            
+            p2 = p1 + (d2-d1)*0.5
+                    
             d1a = d1 - self.gap
             p1b = p1 - self.gap
             
@@ -254,27 +334,69 @@ class Make_instrument(config.Action_with_working_dir, Make_base):
             )
             mask_inside = shape.extrude_profile(prof_inside)
             mask_outside = shape.extrude_profile(prof_outside)
-            
-            item = remainder.copy()
-            item.remove(mask_outside)                
-            remainder.clip(mask_inside)
-            shapes.append(item)
-        shapes.append(remainder)
-        shapes = shapes[::-1]
-        
-        for i, item in enumerate(shapes):
-            item.rotate(0,1,0, 180)
-            item.position_nicely()
-            self.save(item, '%d-of-%d' % (i+1,len(shapes)))
-        
-        size = outer.maximum() * 4.0
-        template = pack.Pack(size,size,5000.0)
-        packables = [ [pack.Packable([item], 0.0, 1.0)] for item in shapes ]
-        [ packed ] = pack.pack(template, packables)
-        self.save(packed.render_print(), 'all-%d' % len(shapes))
-        
-        #self.working.segments = shapes
+            return mask_inside, mask_outside
 
+    def _tapered_socket(
+                self,
+                p1,
+                p3,
+                length,
+                d1,
+                d4,
+                d5
+                ):       
+            d3 = (d1+d4) / 2.0
+            d2 = (d1+d3) / 2.0
+            
+            p2 = p1 + (d2-d1)
+                    
+            d1a = d1 - self.gap
+            p1b = p1 - self.gap
+            
+            d2a = d2 - self.gap
+            d2b = d2 + self.gap
+
+            d3a = d3 - self.gap
+            d3b = d3 + self.gap
+            
+            prof_inside = profile.Profile(
+                [ p1,  p2,  p3,  length+50 ],
+                [ d1a, d2a, d3a, d5 ],
+                [ d1a, d2a, d5,  d5 ],
+            )
+            prof_outside = profile.Profile(
+                [ p1b, p2,  p3,  length+50 ],
+                [ d1,  d2b, d3b, d5 ],
+                [ d1,  d2b, d5,  d5 ],
+            )
+            mask_inside = shape.extrude_profile(prof_inside)
+            mask_outside = shape.extrude_profile(prof_outside)
+            return mask_inside, mask_outside
+
+    def _weld_join(self,z0,z1,zmax,d0,d1,dmax):
+        prof = profile.Profile(
+            [ z1, zmax+50 ],
+            [ dmax, dmax]
+            )
+        mask = shape.extrude_profile(prof)
+        
+        triangle = shape.Loop([
+            (0.5, 0.0),
+            (-0.5, 0.0),
+            (0.0, math.sqrt(0.75)),
+            ]).scale(d0*0.5)
+        dstart = (d0+d1)*0.5
+        for i in xrange(1,5):
+            bump = shape.extrusion(
+                [ dstart*0.5, dmax*0.5 ],
+                [ triangle, triangle ]
+                )
+            bump.rotate(1,0,0,-90)
+            bump.rotate(0,0,1,180+360.0/5*i)
+            bump.move(0,0,z1)
+            mask.add(bump)
+        
+        return mask, mask      
         
 @config.Bool_flag('mill', 'Create shapes for milling (rather than 3D printing).')
 @config.Float_flag('mill_diameter', 'Milling: Bit diameter for milling (affects gap size when packing pieces).')
