@@ -10,10 +10,6 @@ from nesoni import config
 Produce 3D models using the output of "demakein design-*-flute:"
 """)
 @config.Bool_flag('open', 'Open both ends, thus requiring a cork.')
-@config.Float_flag('gap', 
-    'Printing: Amount of gap all around in the joins between segments. '
-    'The best value for this will depend on the accuracy of your printer. '
-    'If a joint is too loose and leaks, it can be sealed using wax or similar.')
 @config.Bool_flag('mill', 'Create shapes for milling (rather than 3D printing).')
 @config.Float_flag('mill_diameter', 'Milling: Bit diameter for milling (affects gap size when packing pieces).')
 @config.Float_flag('mill_length', 'Milling: Wood length for milling.')
@@ -28,8 +24,8 @@ class Make_flute(make.Make_instrument):
     open = False
 
     mill_diameter = 3.0    
-    mill_length = 190.0
-    mill_width = 140.0
+    mill_length = 180.0
+    mill_width = 130.0
     mill_thickness = 19.0
     mill_scheme = 4
     
@@ -148,7 +144,9 @@ class Make_flute(make.Make_instrument):
             )
         
         else:
-            cut1 = spec.inner_hole_positions[2]*0.5+spec.inner_hole_positions[3] * 0.5
+            cut1 = min(spec.hole_positions[3],spec.inner_hole_positions[3])-spec.hole_diameters[3] * 0.75
+            cut1 -= spec.inner(cut1)*0.5
+            #cut1 = spec.inner_hole_positions[2]*0.5+spec.inner_hole_positions[3] * 0.5
             #cut2 = cut1 + (length-cut1)*0.3 + spec.outer.maximum()*0.7
             cut2 = length * 0.62
 
