@@ -15,10 +15,12 @@ from nesoni import config
 Make the head of a whistle instrument.
 """)
 @config.Float_flag('bore')
+@config.Float_flag('outside')
 @config.Float_flag('gap_width')
 @config.Float_flag('gap_length')
 class Make_whistle_head(make.Make):
     bore = 15.0
+    outside = 21.0
     
     gap_width = 0.666 #Formerly 0.5
     gap_length = 0.4 #Formerly 0.25
@@ -34,7 +36,8 @@ class Make_whistle_head(make.Make):
 
     def construct(self):
         bore = self.bore
-        outside = bore * 1.4
+        outside = self.outside
+        #outside = bore * 1.4
         
         bore_length = bore*2.0        
         gap_length = bore * self.gap_length
@@ -221,12 +224,12 @@ class Make_whistle(make.Make_millable_instrument):
         n_holes = len(spec.hole_diameters)
         
         self.make_instrument(
-             inner_profile = spec.inner.clipped(-50,spec.length),
+             inner_profile = spec.inner.clipped(-50, spec.length),
              outer_profile = spec.outer.clipped(0, spec.length-whistle_maker.bore*1.5), #Don't paint over windcutter
              hole_positions = spec.hole_positions,
              hole_diameters = spec.hole_diameters,
              hole_vert_angles = spec.hole_angles,
-             hole_horiz_angles = [0.0]*n_holes,
+             hole_horiz_angles = designer.horiz_angles,
              xpad = [0.0]*n_holes,
              ypad = [0.0]*n_holes,
              with_fingerpad = [True]*n_holes,
@@ -236,18 +239,30 @@ class Make_whistle(make.Make_millable_instrument):
         
         true_length = self.working.instrument.extent().zmax
 
-        cut0 = spec.hole_positions[0] + spec.hole_diameters[0]*0.75
-        cut0 += spec.inner(cut0)*0.5
-        cut1 = spec.hole_positions[3] + spec.hole_diameters[3]*0.75
-        cut1 += spec.inner(cut1)*0.5
-        cut2 = spec.hole_positions[5] + spec.hole_diameters[5]*0.75
-        cut2 += spec.inner(cut2)*0.5
-        cut3 = true_length * 0.7
-        
+        #cut0 = spec.hole_positions[0] + spec.hole_diameters[0]*0.75
+        #cut0 += spec.inner(cut0)*0.5
+        #cut1 = spec.hole_positions[designer.mid_cut] + spec.hole_diameters[designer.mid_cut]*0.75
+        #cut1 += spec.inner(cut1)*0.5
+        #cut2 = spec.hole_positions[-1] + spec.hole_diameters[-1]*0.75
+        #cut2 += spec.inner(cut2)*0.5
+        #cut2 = max(cut2, true_length*0.5)
+        ##cut3 = true_length * 0.7
+        #cut3 = cut1 + (true_length-cut1)*0.5 
+           
         if not self.mill:
-            self.segment([ cut2 ], spec.length, up=True)
+            #self.segment([ cut2 ], spec.length, up=True)
             #self.segment([ cut1, cut2 ], spec.length, up=True)
-            self.segment([ cut0, cut1, cut3 ], spec.length, up=True)
+            #self.segment([ cut0, cut1, cut3 ], spec.length, up=True)
+        
+            for division in designer.divisions:
+                cuts = [ ]
+                for hole, above in division:
+                    cut = spec.hole_positions[hole] + spec.hole_diameters[hole]*0.75
+                    cut += spec.inner(cut)*0.5
+                    cut += (true_length-cut)*above
+                    cuts.append(cut)
+                self.segment(cuts, true_length, up=True)
+        
         else:
             mid1 = spec.hole_positions[2]*0.5+spec.hole_diameters[2]*0.5-spec.hole_diameters[3]*0.5+spec.hole_positions[3]*0.5
             mid2 = spec.hole_positions[5]+spec.hole_diameters[5]
