@@ -27,6 +27,10 @@ class Profile:
         return (1.0-t)*self.high[i-1] + t*self.low[i]
 
 
+    def __repr__(self):
+        return 'Profile' + repr((self.pos,self.low,self.high))
+
+
     def start(self):
         return self.pos[0]
     
@@ -69,7 +73,7 @@ class Profile:
         high = [ self(start, True) ]
         
         for i, p in enumerate(self.pos):
-            if p < start or p > end: continue
+            if p <= start or p >= end: continue
             pos.append(p)
             low.append(self.low[i])
             high.append(self.high[i])
