@@ -88,6 +88,13 @@ class Loop(list):
            sum_y = sum(point[1] for point in self)
         
         return (sum_x/div, sum_y/div)
+
+    def extent(self):
+        xs = [ item[0] for item in self ]
+        ys = [ item[1] for item in self ]
+        return Limits_2(
+            min(xs),max(xs),min(ys),max(ys)
+            )
     
     def scale(self, factor):
         return Loop( (x*factor, y*factor) for x,y in self )
